TurnControl

Struct TurnControl 

pub struct TurnControl { /* private fields */ }
Cheap cloneable control capability for one accepted turn.

Implementations

Source

impl TurnControl

pub async fn steer(&self, prompt: impl Into<Prompt>) -> Result<()>

Injects additional input into the targeted turn.

Errors

Returns an error for an empty prompt, when the turn is not active, when its steering queue is full, or if the driver stops.

pub async fn cancel(&self) -> Result<()>

Cancels the targeted unfinished turn.

Errors

Returns an error when the turn has already finished or if the driver stops.